Revert "default GetLuciAuth to latest SHA1 version"

This reverts commit 864174318210c5c4164ead0f196fd82d0ebbdee4.

Reason for revert: crbug.com/874164

It appears that this CL is not correct for older branches.

Original change's description:
> default GetLuciAuth to latest SHA1 version
> 
> BUG=chromium:871831
> TEST=local unit test
> 
> default to latest SHA1 instead of latest to
> fix old branches.
> 
> Change-Id: Ib14ec566181908a054c14f2d84b48ff5af0e76e6
> (cherry picked from commit dd861a00fcd4134f9eecddf9607dd2af067113aa)
> Reviewed-on: https://chromium-review.googlesource.com/1168242
> Reviewed-by: Gregory Meinke <gmeinke@chromium.org>
> Tested-by: Mike Frysinger <vapier@chromium.org>
> Commit-Queue: Gregory Meinke <gmeinke@chromium.org>

BUG=chromium:871831,chromium:874164

Change-Id: I9f784f96d7c0d250b460eea46080f7204a3725c7
Reviewed-on: https://chromium-review.googlesource.com/1177176
Reviewed-by: Mike Frysinger <vapier@chromium.org>
Commit-Queue: Mike Frysinger <vapier@chromium.org>
Tested-by: Mike Frysinger <vapier@chromium.org>
diff --git a/lib/auth.py b/lib/auth.py
index 7f566ca..8c8ed12 100644
--- a/lib/auth.py
+++ b/lib/auth.py
@@ -19,18 +19,14 @@
 REFRESH_STATUS_CODES = [401]
 
 
-# crbug:871831 default to last sha1 version.
-def _GetAuthUtil(
-    instance_id='git_revision:fd059ace316e4dbcaa5afdcec9ed4a855c4f3c65'):
+def _GetAuthUtil(instance_id='latest'):
   """Returns a path to the authutil binary.
 
   This will download and install the authutil package if it is not already
   deployed.
 
   Args:
-    instance_id: The instance-id of the package to install. Defaults to
-    'git_revision:fd059ace316e4dbcaa5afdcec9ed4a855c4f3c65' which is the last
-    SHA1 version.
+    instance_id: The instance-id of the package to install. Defaults to 'latest'
 
   Returns:
     the path to the authutil binary.